floating_label_inputs library

Classes

FloatingAnimatedInput
A Flutter widget that provides a text input field with a label that animates to a "floating" position when the field is focused or contains text.